@@ -1,27 +1,30 @@
 
+from itertools import product
+
 import networkx as nx
 from scipy.spatial import distance
-from itertools import product
 
 from .abssimcomplex import SimplicialComplex
 
 
 class VietorisRipsComplex(SimplicialComplex):
-    def __init__(self,
-                 points,
-                 epsilon,
-                 labels=None,
-                 distfcn=distance.euclidean):
+    def __init__(
+            self,
+            points,
+            epsilon,
+            labels=None,
+            distfcn=distance.euclidean
+    ):
+        super(VietorisRipsComplex, self).__init__()
         self.pts = points
         self.labels = (range(len(self.pts))
                        if labels is None or len(labels) != len(self.pts)
                        else labels)
         self.epsilon = epsilon
         self.distfcn = distfcn
-        self.network = self.construct_network(self.pts,
-                                              self.labels,
-                                              self.epsilon,
-                                              self.distfcn)
+        self.network = self.construct_network(
+            self.pts, self.labels, self.epsilon, self.distfcn
+        )
         self.import_simplices(map(tuple, nx.find_cliques(self.network)))
 
     def construct_network(self, points, labels, epsilon, distfcn):
